@@ -44,7 +44,7 @@ class CurrentUser(object):
         r.headers.update(headers)
         return utils.URLPatch(r)
 
-    def impersonate(self, user):
+    def impersonate(self, user=None):
         r = requests.Session()
         #r.request = utils.PatchedSession.request
         r.trust_env = False
@@ -52,8 +52,11 @@ class CurrentUser(object):
             'Authorization': 'Bearer %s' % self.token,
             'Accept': 'application/vnd.heroku+json; version=3',
             "X-Heroku-Sudo": "true",
-            "X-Heroku-Sudo-User": user
         })
+        if user:
+            r.headers.update(**{
+                "X-Heroku-Sudo-User": user
+            })
         return utils.URLPatch(r)
 
     def __repr__(self):
@@ -111,7 +114,7 @@ class HerokuOAuth(object):
 
         def auth():
             self.current.next_endpoint = request.endpoint
-            self.current.next_url = request.url
+            self.current.next_url = request.url or "/"
             return self.oauth.authorize(callback=url_for('heroku_auth_login'))
 
         if request.endpoint in ([
